@@ -229,6 +229,9 @@ class CloudRegion(object):
 
         If none of that works, it returns the value in ``default``.
         '''
+        if service_type is None:
+            return self.config.get(key)
+
         for st in self._service_type_manager.get_all_types(service_type):
             value = self.config.get(_make_key(key, st))
             if value is not None:
@@ -249,7 +252,18 @@ class CloudRegion(object):
             'interface', service_type, fallback_to_unprefixed=True)
 
     def get_api_version(self, service_type):
-        return self._get_config('api_version', service_type)
+        version = self._get_config('api_version', service_type)
+        if version:
+            try:
+                float(version)
+            except ValueError:
+                if 'latest' in version:
+                    warnings.warn(
+                        "You have a configured API_VERSION with 'latest' in"
+                        " it. In the context of openstacksdk this doesn't make"
+                        " any sense.")
+                return None
+        return version
 
     def get_default_microversion(self, service_type):
         return self._get_config('default_microversion', service_type)
@@ -275,6 +289,11 @@ class CloudRegion(object):
         value = self._get_config('endpoint_override', service_type)
         if not value:
             value = self._get_config('endpoint', service_type)
+        if not value and self.config.get('auth_type') == 'none':
+            # If endpoint is given and we're using the none auth type,
+            # then the endpoint value is the endpoint_override for every
+            # service.
+            value = self.config.get('auth', {}).get('endpoint')
         return value
 
     def get_connect_retries(self, service_type):
@@ -336,7 +355,6 @@ class CloudRegion(object):
                 verify=verify,
                 cert=cert,
                 timeout=self.config.get('api_timeout'),
-                collect_timing=self.config.get('timing'),
                 discovery_cache=self._discovery_cache)
             self.insert_user_agent()
             # Using old keystoneauth with new os-client-config fails if
@@ -405,6 +423,20 @@ class CloudRegion(object):
 
         return version_request
 
+    def get_all_version_data(self, service_type):
+        # Seriously. Don't think about the existential crisis
+        # that is the next line. You'll wind up in cthulhu's lair.
+        service_type = self.get_service_type(service_type)
+        versions = self.get_session().get_all_version_data(
+            service_type=service_type,
+            interface=self.get_interface(service_type),
+            region_name=self.region_name,
+        )
+        region_versions = versions.get(self.region_name, {})
+        interface_versions = region_versions.get(
+            self.get_interface(service_type), {})
+        return interface_versions.get(service_type, [])
+
     def get_session_client(
             self, service_type, version=None, constructor=adapter.Adapter,
             **kwargs):
@@ -429,8 +461,10 @@ class CloudRegion(object):
                           self.get_status_code_retries(service_type))
         endpoint_override = self.get_endpoint(service_type)
         version = version_request.version
-        min_api_version = version_request.min_api_version
-        max_api_version = version_request.max_api_version
+        min_api_version = (
+            kwargs.pop('min_version', None) or version_request.min_api_version)
+        max_api_version = (
+            kwargs.pop('max_version', None) or version_request.max_api_version)
         # Older neutron has inaccessible discovery document. Nobody noticed
         # because neutronclient hard-codes an append of v2.0. YAY!
         if service_type == 'network':
